pub enum Constraint {
Show 19 variants
Or(Or),
Not(Not),
Try(Try),
Isa(Isa),
Has(Has),
Links(Links),
Kind(Kind),
Sub(Sub),
Owns(Owns),
Relates(Relates),
Plays(Plays),
Value(Value),
Label(Label),
Comparison(Comparison),
Expression(Expression),
FunctionCall(FunctionCall),
Is(Is),
Iid(Iid),
DeleteConcepts(DeleteConcepts),
}Variants
Or(Or)
Not(Not)
Try(Try)
Isa(Isa)
Data
Has(Has)
Links(Links)
Kind(Kind)
Schema
Sub(Sub)
Owns(Owns)
Relates(Relates)
Plays(Plays)
Value(Value)
Label(Label)
Comparison(Comparison)
Function
Expression(Expression)
FunctionCall(FunctionCall)
Is(Is)
Special
Iid(Iid)
DeleteConcepts(DeleteConcepts)
Implementations
Sourceimpl Constraint
impl Constraint
Sourcepub fn merge(
field: &mut Option<Constraint>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Constraint>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.